1.1. Requirements — PyPAGO 1.0.1 documentation

# 1.1. Requirements

Prior to using PyPAGO, the user must install Python and the libraries that are listed in Table 1.1. These packages can be installed by using package managers (Synaptic, apt, macport, fink).

Table 1.1 List of the Python libraries used in PyPAGO
Library | Website
--- | ---
`numpy` | http://www.numpy.org/
`matplotlib` | http://matplotlib.org/
`netCDF4` | https://github.com/Unidata/netcdf4-python/
`mpl_toolkits.basemap` | http://matplotlib.org/basemap/

New Python users are invited to use the Anaconda Scientific Python distribution, which automatically installs Python and the most used libraries, among which `numpy`, `matplotlib` and `netCDF4`. The `mpl_toolkits.basemap` library, which is not included in the default Anaconda distribution, can be installed by using the conda command as follows:

    conda install basemap